Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1164)

Unified Diff: src/ast/scopeinfo.cc

Issue 2368613002: [modules] Simplify treatment of empty imports. (Closed)
Patch Set: Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/ast/modules.cc ('k') | src/ast/scopes.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/ast/scopeinfo.cc
diff --git a/src/ast/scopeinfo.cc b/src/ast/scopeinfo.cc
index c2ed3aeb539be34452e09c64f3d0a44a04a2113d..5354b8d737800c4ac2cd57d6fc4b3e6ffd8dd9e4 100644
--- a/src/ast/scopeinfo.cc
+++ b/src/ast/scopeinfo.cc
@@ -871,13 +871,13 @@ Handle<ModuleInfo> ModuleInfo::New(Isolate* isolate, Zone* zone,
}
}
- // Serialize special imports.
- Handle<FixedArray> special_imports =
- isolate->factory()->NewFixedArray(descr->special_imports().length());
+ // Serialize namespace imports.
+ Handle<FixedArray> namespace_imports =
+ isolate->factory()->NewFixedArray(descr->namespace_imports().length());
{
int i = 0;
- for (auto entry : descr->special_imports()) {
- special_imports->set(i++, *entry->Serialize(isolate));
+ for (auto entry : descr->namespace_imports()) {
+ namespace_imports->set(i++, *entry->Serialize(isolate));
}
}
@@ -899,7 +899,7 @@ Handle<ModuleInfo> ModuleInfo::New(Isolate* isolate, Zone* zone,
result->set(kModuleRequestsIndex, *module_requests);
result->set(kSpecialExportsIndex, *special_exports);
result->set(kRegularExportsIndex, *regular_exports);
- result->set(kSpecialImportsIndex, *special_imports);
+ result->set(kNamespaceImportsIndex, *namespace_imports);
result->set(kRegularImportsIndex, *regular_imports);
return result;
}
« no previous file with comments | « src/ast/modules.cc ('k') | src/ast/scopes.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698